//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[Improvement](index.md)/[discard](discard.md)

# discard

[common]\
val [discard](discard.md): [Tile](../../mahjongutils.models/-tile/index.md)

摸上改良张后的弃牌
